package com.ruoyi.zongzhi.service;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcExtworkSafetyadmin;

/**
 * 网络安全官Service接口
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
public interface ITcExtworkSafetyadminService 
{
    /**
     * 查询网络安全官
     * 
     * @param id 网络安全官主键
     * @return 网络安全官
     */
    public TcExtworkSafetyadmin selectTcExtworkSafetyadminById(Long id);

    /**
     * 查询网络安全官列表
     * 
     * @param tcExtworkSafetyadmin 网络安全官
     * @return 网络安全官集合
     */
    public List<TcExtworkSafetyadmin> selectTcExtworkSafetyadminList(TcExtworkSafetyadmin tcExtworkSafetyadmin);

    /**
     * 新增网络安全官
     * 
     * @param tcExtworkSafetyadmin 网络安全官
     * @return 结果
     */
    public int insertTcExtworkSafetyadmin(TcExtworkSafetyadmin tcExtworkSafetyadmin);

    /**
     * 修改网络安全官
     * 
     * @param tcExtworkSafetyadmin 网络安全官
     * @return 结果
     */
    public int updateTcExtworkSafetyadmin(TcExtworkSafetyadmin tcExtworkSafetyadmin);

    /**
     * 批量删除网络安全官
     * 
     * @param ids 需要删除的网络安全官主键集合
     * @return 结果
     */
    public int deleteTcExtworkSafetyadminByIds(Long[] ids);

    /**
     * 删除网络安全官信息
     * 
     * @param id 网络安全官主键
     * @return 结果
     */
    public int deleteTcExtworkSafetyadminById(Long id);
}
