package com.ruoyi.zongzhi.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.zongzhi.domain.TcExtworkSafetyadmin;
import com.ruoyi.zongzhi.service.ITcExtworkSafetyadminService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 网络安全官Controller
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
@RestController
@RequestMapping("/zongzhi/safetyadmin")
@Api(tags = "网络安全官")
public class TcExtworkSafetyadminController extends BaseController
{
    @Autowired
    private ITcExtworkSafetyadminService tcExtworkSafetyadminService;

    /**
     * 查询网络安全官列表
     */

    @GetMapping("/list")
    public TableDataInfo list(TcExtworkSafetyadmin tcExtworkSafetyadmin)
    {
        startPage();
        List<TcExtworkSafetyadmin> list = tcExtworkSafetyadminService.selectTcExtworkSafetyadminList(tcExtworkSafetyadmin);
        return getDataTable(list);
    }

    /**
     * 导出网络安全官列表
     */

    @PostMapping("/export")
    public void export(HttpServletResponse response, TcExtworkSafetyadmin tcExtworkSafetyadmin)
    {
        List<TcExtworkSafetyadmin> list = tcExtworkSafetyadminService.selectTcExtworkSafetyadminList(tcExtworkSafetyadmin);
        ExcelUtil<TcExtworkSafetyadmin> util = new ExcelUtil<TcExtworkSafetyadmin>(TcExtworkSafetyadmin.class);
        util.exportExcel(response, list, "网络安全官数据");
    }

    /**
     * 获取网络安全官详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcExtworkSafetyadminService.selectTcExtworkSafetyadminById(id));
    }

    /**
     * 新增网络安全官
     */

    @PostMapping
    public AjaxResult add(@RequestBody TcExtworkSafetyadmin tcExtworkSafetyadmin)
    {
        tcExtworkSafetyadmin.setIsStatus(true);
        return toAjax(tcExtworkSafetyadminService.insertTcExtworkSafetyadmin(tcExtworkSafetyadmin));
    }

    /**
     * 修改网络安全官
     */

    @PutMapping
    public AjaxResult edit(@RequestBody TcExtworkSafetyadmin tcExtworkSafetyadmin)
    {
        return toAjax(tcExtworkSafetyadminService.updateTcExtworkSafetyadmin(tcExtworkSafetyadmin));
    }

    /**
     * 删除网络安全官
     */

	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcExtworkSafetyadminService.deleteTcExtworkSafetyadminByIds(ids));
    }
}
